@@ -39,7 +39,7 @@ use SNMP::Info::LLDP;
 
 use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
 
-$VERSION = '3.21_001';
+$VERSION = '3.07';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -89,6 +89,22 @@ sub model {
     return;
 }
 
+# Use Q-BRIDGE-MIB
+
+sub fw_mac {
+    my $l3  = shift;
+    my $partial = shift;
+
+    return $l3->qb_fw_mac($partial);
+}
+
+sub fw_port {
+    my $l3  = shift;
+    my $partial = shift;
+
+    return $l3->qb_fw_port($partial);
+}
+
 1;
 __END__
 
@@ -180,6 +196,20 @@ See documentation in L<SNMP::Info::LLDP> for details.
 These are methods that return tables of information in the form of a reference
 to a hash.
 
+=head2 Overrides
+
+=over
+
+=item $pica8->fw_mac()
+
+Use the F<Q-BRIDGE-MIB> instead of F<BRIDGE-MIB>
+
+=item $pica8->fw_port()
+
+Use the F<Q-BRIDGE-MIB> instead of F<BRIDGE-MIB>
+
+=back
+
 =head2 Table Methods imported from SNMP::Info::Layer3
 
 See documentation in L<SNMP::Info::Layer3> for details.
